Function oxygengine_ha_renderer::math::num_integer::sqrt
source · pub fn sqrt<T>(x: T) -> Twhere
T: Roots,Expand description
Returns the truncated principal square root of an integer – see Roots::sqrt.
pub fn sqrt<T>(x: T) -> Twhere
T: Roots,Returns the truncated principal square root of an integer – see Roots::sqrt.