pub type LinearTransition<T, Progress = f32> = Transition<T, IdentityProgressMapper, Progress>;
A convenience structure for storing a linear progression from one value to another.

Aliased Type

struct LinearTransition<T, Progress = f32> {
    pub start: T,
    pub end: T,
    pub progress: Progress,
    pub progress_mapper: IdentityProgressMapper,
}

Fields

start: T

The value when progress gets close to 0.

end: T

The value when progress gets close to 1.

progress: Progress

Expected to be between 0 and 1.

progress_mapper: IdentityProgressMapper

Functor that maps the current progress value to a LERP factor.

Implementations

source

impl<T, F, Progress> Transition<T, F, Progress>

source

pub fn with_mapper( start: T, end: T, progress_mapper: F ) -> Transition<T, F, Progress>where Progress: Zero,

Creates a new Transition from start and end values and progress_mapper, setting progress to zero.

source

pub fn with_mapper_and_progress( start: T, end: T, progress_mapper: F, progress: Progress ) -> Transition<T, F, Progress>

Creates a new Transition from start, end, progress_mapper and progress values.

source

pub fn into_range(self) -> Range<T>

Converts this into a Range, dropping the progress and progress_mapper values.

source

impl<T, F, Progress> Transition<T, F, Progress>where F: ProgressMapper<Progress>,

source

pub fn into_current(self) -> Twhere T: Lerp<Progress, Output = T>, Progress: Clamp<Progress> + Zero + One,

Gets the transition’s current state, clamping progress to [0;1].

source

pub fn into_current_unclamped(self) -> Twhere T: Lerp<Progress, Output = T>,

Gets the transition’s current state using the progress value as-is.

source

pub fn into_current_precise(self) -> Twhere T: Lerp<Progress, Output = T>, Progress: Clamp<Progress> + Zero + One,

Gets the transition’s current state, clamping progress to [0;1].

source

pub fn into_current_unclamped_precise(self) -> Twhere T: Lerp<Progress, Output = T>,

Gets the transition’s current state using the progress value as-is.

source

pub fn current<'a>(&'a self) -> Twhere &'a T: Lerp<Progress, Output = T>, Progress: Copy + Clamp<Progress> + Zero + One,

Gets the transition’s current state, clamping progress to [0;1].

source

pub fn current_unclamped<'a>(&'a self) -> Twhere &'a T: Lerp<Progress, Output = T>, Progress: Copy,

Gets the transition’s current state using the progress value as-is.

source

pub fn current_precise<'a>(&'a self) -> Twhere &'a T: Lerp<Progress, Output = T>, Progress: Copy + Clamp<Progress> + Zero + One,

Gets the transition’s current state, clamping progress to [0;1].

source

pub fn current_unclamped_precise<'a>(&'a self) -> Twhere &'a T: Lerp<Progress, Output = T>, Progress: Copy,

Gets the transition’s current state using the progress value as-is.

source

impl<T, Progress> Transition<T, IdentityProgressMapper, Progress>

source

pub fn new(start: T, end: T) -> Transition<T, IdentityProgressMapper, Progress>where Progress: Zero,

Creates a new LinearTransition from start and end values, setting progress to zero.

source

pub fn with_progress( start: T, end: T, progress: Progress ) -> Transition<T, IdentityProgressMapper, Progress>

Creates a new LinearTransition from start, end and progress values.