pub type Rect3 = Rect3<Scalar, Scalar>;

Aliased Type

struct Rect3 {
    pub x: f32,
    pub y: f32,
    pub z: f32,
    pub w: f32,
    pub h: f32,
    pub d: f32,
}

Fields

x: f32

X position of the bottom-left-near corner.

y: f32

Y position of the bottom-left-near corner.

z: f32

Z position of the bottom-left-near corner.

w: f32

Width.

h: f32

Height, with Y axis going upwards.

d: f32

Depth, with Z axis going forwards.

Implementations

source

impl<P, E> Rect3<P, E>

source

pub fn new(x: P, y: P, z: P, w: E, h: E, d: E) -> Rect3<P, E>

Creates a new rectangle from position elements and extent elements.

source

pub fn position(self) -> Vec3<P>

Gets this rectangle’s position.

source

pub fn set_position(&mut self, p: Vec3<P>)

Sets this rectangle’s position.

source

pub fn extent(self) -> Extent3<E>

Gets this rectangle’s extent (size).

source

pub fn set_extent(&mut self, e: Extent3<E>)

Sets this rectangle’s extent (size).

source

pub fn position_extent(self) -> (Vec3<P>, Extent3<E>)

Gets this rectangle’s position and extent (size).

source

pub fn map<DP, DE, PF, EF>(self, pf: PF, ef: EF) -> Rect3<DP, DE>where PF: FnMut(P) -> DP, EF: FnMut(E) -> DE,

Returns this rectangle, converted with the given closures (one for position elements, the other for extent elements).

source

pub fn as_<DP, DE>(self) -> Rect3<DP, DE>where P: AsPrimitive<DP>, DP: 'static + Copy, E: AsPrimitive<DE>, DE: 'static + Copy,

Converts this rectangle to a rectangle of another type, using the as conversion.

source

impl<T> Rect3<T, T>where T: Copy + Add<T, Output = T>,

source

pub fn into_aabb(self) -> Aabb<T>

Converts this into the matching axis-aligned bounding shape representation.

source

pub fn contains_point(self, p: Vec3<T>) -> boolwhere T: PartialOrd<T>,

Does this rectangle contain the given point ?

source

pub fn contains_rect3(self, other: Rect3<T, T>) -> boolwhere T: PartialOrd<T>,

Does this rectangle fully contain the given one ?

source

pub fn collides_with_rect3(self, other: Rect3<T, T>) -> boolwhere T: PartialOrd<T>,

Does this rectangle collide with another ?

source

pub fn center(self) -> Vec3<T>where T: One + Div<T, Output = T>,

Gets this rectangle’s center.

source

impl<T> Rect3<T, T>where T: PartialOrd<T> + Sub<T, Output = T> + Add<T, Output = T> + Copy,

source

pub fn expanded_to_contain_point(self, p: Vec3<T>) -> Rect3<T, T>where T: PartialOrd<T>,

Returns this shape so that it contains the given point.

source

pub fn expand_to_contain_point(&mut self, p: Vec3<T>)where T: PartialOrd<T>,

Expands this shape so that it contains the given point.

source

pub fn union(self, other: Rect3<T, T>) -> Rect3<T, T>

Gets the smallest rectangle that contains both this one and another.

source

pub fn intersection(self, other: Rect3<T, T>) -> Rect3<T, T>

Gets the largest rectangle contained by both this one and another.

source

pub fn expand_to_contain(&mut self, other: Rect3<T, T>)

Sets this rectangle to the union of itself with another.

source

pub fn intersect(&mut self, other: Rect3<T, T>)

Sets this rectangle to the intersection of itself with another.

source

pub fn collision_vector_with_rect3(self, other: Rect3<T, T>) -> Vec3<T>where T: One + Div<T, Output = T>,

Gets a vector that tells how much self penetrates other.

source

pub fn split_at_x(self, sp: T) -> [Rect3<T, T>; 2]

Splits this shape in two, by a straight plane along the x axis. The returned tuple is (low, high).

Panics

sp is assumed to be a position along the x axis that is within this shape’s bounds.

source

pub fn split_at_y(self, sp: T) -> [Rect3<T, T>; 2]

Splits this shape in two, by a straight plane along the y axis. The returned tuple is (low, high).

Panics

sp is assumed to be a position along the y axis that is within this shape’s bounds.

source

pub fn split_at_z(self, sp: T) -> [Rect3<T, T>; 2]

Splits this shape in two, by a straight plane along the z axis. The returned tuple is (low, high).

Panics

sp is assumed to be a position along the z axis that is within this shape’s bounds.